@@ -1,3 +1,5 @@
+( cd usr/lib ; rm -rf xserver )
+( cd usr/lib ; ln -sf ../../etc/X11/xserver xserver )
 ( cd usr/lib ; rm -rf modules )
 ( cd usr/lib ; ln -sf xorg/modules modules )
 ( cd usr/bin ; rm -rf inb )
